package com.zehong.system.mapper;

import java.util.List;
import com.zehong.system.domain.TDangersRectifications;

/**
 * 隐患及整改Mapper接口
 *
 * @author zehong
 * @date 2026-03-16
 */
public interface TDangersRectificationsMapper
{
    /**
     * 查询隐患及整改
     *
     * @param id 隐患及整改ID
     * @return 隐患及整改
     */
    public TDangersRectifications selectTDangersRectificationsById(Long id);

    /**
     * 查询隐患及整改列表
     *
     * @param tDangersRectifications 隐患及整改
     * @return 隐患及整改集合
     */
    public List<TDangersRectifications> selectTDangersRectificationsList(TDangersRectifications tDangersRectifications);

    /**
     * 新增隐患及整改
     *
     * @param tDangersRectifications 隐患及整改
     * @return 结果
     */
    public int insertTDangersRectifications(TDangersRectifications tDangersRectifications);

    /**
     * 修改隐患及整改
     *
     * @param tDangersRectifications 隐患及整改
     * @return 结果
     */
    public int updateTDangersRectifications(TDangersRectifications tDangersRectifications);

    /**
     * 删除隐患及整改
     *
     * @param id 隐患及整改ID
     * @return 结果
     */
    public int deleteTDangersRectificationsById(Long id);

    /**
     * 批量删除隐患及整改
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTDangersRectificationsByIds(Long[] ids);
}