package com.zehong.web.controller.energency;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TDangersRectifications;
import com.zehong.system.service.ITDangersRectificationsService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 隐患及整改Controller
 *
 * @author zehong
 * @date 2026-03-16
 */
@RestController
@RequestMapping("/dangers/rectifications")
public class TDangersRectificationsController extends BaseController
{
    @Autowired
    private ITDangersRectificationsService tDangersRectificationsService;

    /**
     * 查询隐患及整改列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TDangersRectifications tDangersRectifications)
    {
        startPage();
        List<TDangersRectifications> list = tDangersRectificationsService.selectTDangersRectificationsList(tDangersRectifications);
        return getDataTable(list);
    }

    /**
     * 导出隐患及整改列表
     */
    @Log(title = "隐患及整改", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TDangersRectifications tDangersRectifications)
    {
        List<TDangersRectifications> list = tDangersRectificationsService.selectTDangersRectificationsList(tDangersRectifications);
        ExcelUtil<TDangersRectifications> util = new ExcelUtil<TDangersRectifications>(TDangersRectifications.class);
        return util.exportExcel(list, "隐患及整改数据");
    }

    /**
     * 获取隐患及整改详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tDangersRectificationsService.selectTDangersRectificationsById(id));
    }

    /**
     * 新增隐患及整改
     */
    @Log(title = "隐患及整改", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDangersRectifications tDangersRectifications)
    {
        return toAjax(tDangersRectificationsService.insertTDangersRectifications(tDangersRectifications));
    }

    /**
     * 修改隐患及整改
     */
    @Log(title = "隐患及整改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDangersRectifications tDangersRectifications)
    {
        return toAjax(tDangersRectificationsService.updateTDangersRectifications(tDangersRectifications));
    }

    /**
     * 删除隐患及整改
     */
    @Log(title = "隐患及整改", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tDangersRectificationsService.deleteTDangersRectificationsByIds(ids));
    }
}